#include <iostream>
#include <algorithm>
#include <vector>

using namespace std;

const int INF = 1e9;
const int T = 3000;

struct Tree{
    struct Segment{
        int left, right;

        Segment(int _left = 0, int _right = 0) : left(_left), right(_right) {}

        int size(){
            return right - left;
        }

        int mid(){
            return (left + right) / 2;
        }

        Segment leftMid(){
            return Segment(left, mid());
        }

        Segment midRight(){
            return Segment(mid(), right);
        }

        bool inside(Segment seg){
            return left >= seg.left && right <= seg.right;
        }
    };

    bool cross(Segment seg1, Segment seg2){
        if (seg1.left > seg2.left){
            swap(seg1, seg2);
        }

        return seg1.right > seg2.left;
    }

    vector<int> tree;

    Tree() {}

    Tree(int n){
        resize(n);
    }

    void resize(int n){
        tree.resize(4 * n, -1);
    }

    void updElem(int pos, Segment curSeg, Segment updSeg, int newVal){
        if (!cross(curSeg, updSeg)){
            return;
        }
        if (curSeg.inside(updSeg)){
            tree[pos] = newVal;
            return;
        }

        updElem(2 * pos + 1, curSeg.leftMid(), updSeg, newVal);
        updElem(2 * pos + 2, curSeg.midRight(), updSeg, newVal);

        tree[pos] = max(tree[2 * pos + 1], tree[2 * pos + 2]);
    }

    int getMax(int pos, Segment curSeg, Segment query){
        if (!cross(curSeg, query)){
            return -INF;
        }
        if (curSeg.inside(query)){
            return tree[pos];
        }

        return max(getMax(2 * pos + 1, curSeg.leftMid(), query), getMax(2 * pos + 2, curSeg.midRight(), query));
    }
};

int f(int r, int x, vector<vector<int> > &d, vector<int> &nxt){
    int ans = 0;
    for (int i = 0; i < r / T; ++i){
        int left = 0, right = d[i].size() + 1;
        while (right - left > 1){
            int mid = (left + right) / 2;
            if (-d[i][mid - 1] > x){
                left = mid;
            }
            else{
                right = mid;
            }
        }
        ans += left;
    }
    vector<int> arr;
    for (int i = r / T * T; i <= r; ++i){
        arr.push_back(-nxt[i]);
    }
    sort(arr.begin(), arr.end());
    //for (int i = 0; i < arr.size(); ++i){
        //cout << arr[i] << " ";
    //}
    //cout << endl;
    int left = 0, right = arr.size() + 1;
    while (right - left > 1){
        int mid = (left + right) / 2;
        if (-arr[mid - 1] > x){
            left = mid;
        }
        else{
            right = mid;
        }
    }
    ans += left;
    //cout << ans << endl;
    return ans;
}

int f(int l, int r, int x, vector<vector<int> > &d, vector<int> &nxt){
    //cout << l << " " << r << " " << x << " " << f(r, x, d) << endl;
    return f(r, x, d, nxt) - f(l, x, d, nxt);
}

int main(){
    int n, m;
    cin >> n >> m;
    vector<int> a(m), b(n);
    for (int i = 0; i < m; ++i){
        cin >> a[i];
        --a[i];
    }
    for (int i = 0; i < n; ++i){
        cin >> b[i];
        --b[i];
    }

    vector<char> used(n);
    int j = 0;
    vector<int> arr;
    for (int i = 0; i < m; ++i){
        if (!used[a[i]]){
            while (a[i] != b[j]){
                arr.push_back(b[j]);
                used[b[j]] = true;
                ++j;
            }
            arr.push_back(a[i]);
            ++j;
            used[a[i]] = true;
        }
        else{
            arr.push_back(a[i]);;
        }
    }
    vector<vector<int> > s(n);
    for (int i = 0; i < arr.size(); ++i){
        s[arr[i]].push_back(i);
    }
    vector<int> nxt(arr.size());
    for (int i = 0; i < n; ++i){
        for (int k = 0; k < s[i].size() - 1; ++k){
            nxt[s[i][k]] = s[i][k + 1];
        }
        nxt[s[i][s[i].size() - 1]] = arr.size();
    }
    vector<vector<int> > d(arr.size() / T + 1);
    j = 0;
    for (int i = 0; i < d.size(); ++i){
        for (int k = 0; k < T && j < nxt.size(); ++k, ++j){
            d[i].push_back(-nxt[j]);
        }
        sort(d[i].begin(), d[i].end());
    }
    vector<int> ans(arr.size());
    for (int i = 0; i < arr.size(); ++i){
        if (nxt[i] != arr.size()){
            ans[i] = f(i, nxt[i] - 1, nxt[i], d, nxt);
        }
        else{
            ans[i] = n - 1;
        }
    }
    cout << ans.size() << endl;
    for (int i = 0; i < ans.size(); ++i){
        cout << ans[i] + 1 << " ";
    }

    return 0;
}
/*
4 5
4 1 2 4 4
4 3 2 1
*/
